slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPViewFromOptions

View from options

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPViewFromOptions(PEP pep,PetscObject obj,const char name[])

Collective on PEP

### Input Parameters

| pep | - the eigensolver context
| obj | - optional object
| name | - command line option

### See Also

PEPView(), PEPCreate()

### Level

intermediate

### Location

src/pep/interface/pepview.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages